==> spring-cloud-contract-verifier-3.1.2-sources.jar: org/springframework/cloud/contract/verifier/util/ContentUtils.java <==
package org.springframework.cloud.contract.verifier.util;
import java.lang.*;
import java.util.*;
import java.io.*;
import java.net.*;
import groovy.lang.*;
import groovy.util.*;
import static org.apache.commons.text.StringEscapeUtils.escapeJava;
import static org.apache.commons.text.StringEscapeUtils.escapeJson;
import static org.apache.commons.text.StringEscapeUtils.escapeXml11;
import static org.apache.commons.text.StringEscapeUtils.unescapeXml;
import static org.springframework.cloud.contract.verifier.util.ContentType.DEFINED;
import static org.springframework.cloud.contract.verifier.util.ContentType.JSON;
import static org.springframework.cloud.contract.verifier.util.ContentType.UNKNOWN;
import static org.springframework.cloud.contract.verifier.util.ContentType.XML;

@groovy.transform.CompileStatic() public class ContentUtils
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
;
public static final groovy.lang.Closure GET_STUB_SIDE = null;
public static final groovy.lang.Closure GET_TEST_SIDE = null;
public static final java.util.function.Function GET_STUB_SIDE_FUNCTION = null;
public static final java.util.function.Function GET_TEST_SIDE_FUNCTION = null;
protected static  java.lang.Object convertDslPropsToTemporaryRegexPatterns(java.lang.Object parsedJson) { return (java.lang.Object)null;}
@groovy.transform.Generated() @groovy.transform.Internal() @java.beans.Transient() public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setMetaClass(groovy.lang.MetaClass mc) { }
public static  java.lang.Object extractValue(groovy.lang.GString bodyAsValue, org.springframework.cloud.contract.verifier.util.ContentType contentType, groovy.lang.Closure valueProvider) { return (java.lang.Object)null;}
public static  java.lang.Object extractValue(groovy.lang.GString bodyAsValue, org.springframework.cloud.contract.verifier.util.ContentType contentType, java.util.function.Function valueProvider) { return (java.lang.Object)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType getClientContentType(groovy.lang.GString bodyAsValue) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType getClientContentType(java.lang.String bodyAsValue) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType getClientContentType(java.lang.Object bodyAsValue) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType getClientContentType(java.lang.Object bodyAsValue, org.springframework.cloud.contract.spec.internal.Headers headers) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType getClientContentType(java.util.Map bodyAsValue) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType getClientContentType(java.util.List bodyAsValue) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  org.codehaus.groovy.runtime.GStringImpl extractValueForGString(groovy.lang.GString bodyAsValue, groovy.lang.Closure valueProvider) { return (org.codehaus.groovy.runtime.GStringImpl)null;}
public static  java.lang.Object extractValue(groovy.lang.GString bodyAsValue, java.util.function.Function valueProvider) { return (java.lang.Object)null;}
public static  java.lang.Object extractValue(groovy.lang.GString bodyAsValue, groovy.lang.Closure valueProvider) { return (java.lang.Object)null;}
protected static  java.lang.Object transformJSONStringValue(java.lang.Object obj, groovy.lang.Closure valueProvider) { return (java.lang.Object)null;}
protected static  java.lang.Object transformJSONStringValue(org.springframework.cloud.contract.spec.internal.DslProperty dslProperty, groovy.lang.Closure valueProvider) { return (java.lang.Object)null;}
protected static  java.lang.Object transformJSONStringValue(java.util.regex.Pattern pattern, groovy.lang.Closure valueProvider) { return (java.lang.Object)null;}
protected static  java.lang.Object transformJSONStringValue(org.springframework.cloud.contract.spec.internal.OptionalProperty optional, groovy.lang.Closure valueProvider) { return (java.lang.Object)null;}
protected static  java.lang.Object transformJSONStringValue(org.springframework.cloud.contract.spec.internal.ExecutionProperty property, groovy.lang.Closure valueProvider) { return (java.lang.Object)null;}
protected static  java.lang.Object convertDslPropsToTemporaryRegexPatterns(java.lang.Object parsedJson, groovy.lang.Closure parsingClosure) { return (java.lang.Object)null;}
public static  java.lang.Object returnParsedObject(java.lang.Object object) { return (java.lang.Object)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType recognizeContentTypeFromHeader(org.springframework.cloud.contract.spec.internal.Headers headers, groovy.lang.Closure<java.lang.Object> closure) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType recognizeContentTypeFromHeader(org.springframework.cloud.contract.spec.internal.Headers headers) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType recognizeContentTypeFromTestHeader(org.springframework.cloud.contract.spec.internal.Headers headers) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  org.springframework.cloud.contract.spec.internal.MatchingStrategy.Type getEqualsTypeFromContentType(org.springframework.cloud.contract.verifier.util.ContentType contentType) { return (org.springframework.cloud.contract.spec.internal.MatchingStrategy.Type)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType recognizeContentTypeFromContent(groovy.lang.GString gstring) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType recognizeContentTypeFromContent(java.util.Map jsonMap) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType recognizeContentTypeFromContent(byte... bytes) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType recognizeContentTypeFromContent(java.util.List jsonList) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType recognizeContentTypeFromContent(java.lang.String string) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType recognizeContentTypeFromContent(java.lang.Number number) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType recognizeContentTypeFromContent(java.lang.Object object) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  boolean isJsonType(groovy.lang.GString gstring) { return false;}
public static  boolean isXmlType(groovy.lang.GString gString) { return false;}
public static  org.springframework.cloud.contract.verifier.util.ContentType recognizeContentTypeFromMatchingStrategy(org.springframework.cloud.contract.spec.internal.MatchingStrategy.Type type) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  java.lang.String getGroovyMultipartFileParameterContent(java.lang.String propertyName, org.springframework.cloud.contract.spec.internal.NamedProperty propertyValue, groovy.lang.Closure<java.lang.String> bytesFromFile) { return (java.lang.String)null;}
public static  java.lang.String getGroovyMultipartFileParameterContent(java.lang.String propertyName, org.springframework.cloud.contract.spec.internal.NamedProperty propertyValue, java.util.function.Function<org.springframework.cloud.contract.spec.internal.FromFileProperty, java.lang.String> bytesFromFile) { return (java.lang.String)null;}
public static  java.lang.String getJavaMultipartFileParameterContent(java.lang.String propertyName, org.springframework.cloud.contract.spec.internal.NamedProperty propertyValue, java.util.function.Function<org.springframework.cloud.contract.spec.internal.FromFileProperty, java.lang.String> bytesFromFile) { return (java.lang.String)null;}
public static  java.lang.String getJavaMultipartFileParameterContent(java.lang.String propertyName, org.springframework.cloud.contract.spec.internal.NamedProperty propertyValue, groovy.lang.Closure<java.lang.String> bytesFromFile) { return (java.lang.String)null;}
public static  java.lang.String namedPropertyName(org.springframework.cloud.contract.spec.internal.NamedProperty property, java.lang.String quote) { return (java.lang.String)null;}
public static  java.lang.String namedContentTypeNameIfPresent(org.springframework.cloud.contract.spec.internal.NamedProperty property, java.lang.String quote) { return (java.lang.String)null;}
public static  java.lang.String groovyNamedPropertyValue(org.springframework.cloud.contract.spec.internal.NamedProperty property, java.lang.String quote, groovy.lang.Closure<java.lang.String> bytesFromFile) { return (java.lang.String)null;}
public static  java.lang.String javaNamedPropertyValue(org.springframework.cloud.contract.spec.internal.NamedProperty property, java.lang.String quote, groovy.lang.Closure<java.lang.String> bytesFromFile) { return (java.lang.String)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType evaluateClientSideContentType(org.springframework.cloud.contract.spec.internal.Headers contractHeaders, java.lang.Object body) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType evaluateServerSideContentType(org.springframework.cloud.contract.spec.internal.Headers contractHeaders, java.lang.Object body) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  groovy.util.XmlSlurper getXmlSlurperWithDefaultErrorHandler() { return (groovy.util.XmlSlurper)null;}
}

==> spring-cloud-contract-verifier-4.0.4-sources.jar: org/springframework/cloud/contract/verifier/util/ContentUtils.java <==
package org.springframework.cloud.contract.verifier.util;
import static org.springframework.cloud.contract.verifier.util.ContentType.DEFINED;
import static org.springframework.cloud.contract.verifier.util.ContentType.JSON;
import static org.springframework.cloud.contract.verifier.util.ContentType.UNKNOWN;
import static org.springframework.cloud.contract.verifier.util.ContentType.XML;

@groovy.transform.CompileStatic() public class ContentUtils
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
;
public static final groovy.lang.Closure GET_STUB_SIDE = null;
public static final groovy.lang.Closure GET_TEST_SIDE = null;
public static final java.util.function.Function GET_STUB_SIDE_FUNCTION = null;
public static final java.util.function.Function GET_TEST_SIDE_FUNCTION = null;
protected static  java.lang.Object convertDslPropsToTemporaryRegexPatterns(java.lang.Object parsedJson) { return (java.lang.Object)null;}
@groovy.transform.Generated() @groovy.transform.Internal() @java.beans.Transient() public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setMetaClass(groovy.lang.MetaClass mc) { }
public static  java.lang.Object extractValue(groovy.lang.GString bodyAsValue, org.springframework.cloud.contract.verifier.util.ContentType contentType, groovy.lang.Closure valueProvider) { return (java.lang.Object)null;}
public static  java.lang.Object extractValue(groovy.lang.GString bodyAsValue, org.springframework.cloud.contract.verifier.util.ContentType contentType, java.util.function.Function valueProvider) { return (java.lang.Object)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType getClientContentType(groovy.lang.GString bodyAsValue) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType getClientContentType(java.lang.String bodyAsValue) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType getClientContentType(java.lang.Object bodyAsValue) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType getClientContentType(java.lang.Object bodyAsValue, org.springframework.cloud.contract.spec.internal.Headers headers) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType getClientContentType(java.util.Map bodyAsValue) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType getClientContentType(java.util.List bodyAsValue) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  org.codehaus.groovy.runtime.GStringImpl extractValueForGString(groovy.lang.GString bodyAsValue, groovy.lang.Closure valueProvider) { return (org.codehaus.groovy.runtime.GStringImpl)null;}
public static  java.lang.Object extractValue(groovy.lang.GString bodyAsValue, java.util.function.Function valueProvider) { return (java.lang.Object)null;}
public static  java.lang.Object extractValue(groovy.lang.GString bodyAsValue, groovy.lang.Closure valueProvider) { return (java.lang.Object)null;}
protected static  java.lang.Object transformJSONStringValue(java.lang.Object obj, groovy.lang.Closure valueProvider) { return (java.lang.Object)null;}
protected static  java.lang.Object transformJSONStringValue(org.springframework.cloud.contract.spec.internal.DslProperty dslProperty, groovy.lang.Closure valueProvider) { return (java.lang.Object)null;}
protected static  java.lang.Object transformJSONStringValue(java.util.regex.Pattern pattern, groovy.lang.Closure valueProvider) { return (java.lang.Object)null;}
protected static  java.lang.Object transformJSONStringValue(org.springframework.cloud.contract.spec.internal.OptionalProperty optional, groovy.lang.Closure valueProvider) { return (java.lang.Object)null;}
protected static  java.lang.Object transformJSONStringValue(org.springframework.cloud.contract.spec.internal.ExecutionProperty property, groovy.lang.Closure valueProvider) { return (java.lang.Object)null;}
protected static  java.lang.Object convertDslPropsToTemporaryRegexPatterns(java.lang.Object parsedJson, groovy.lang.Closure parsingClosure) { return (java.lang.Object)null;}
public static  java.lang.Object returnParsedObject(java.lang.Object object) { return (java.lang.Object)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType recognizeContentTypeFromHeader(org.springframework.cloud.contract.spec.internal.Headers headers, groovy.lang.Closure<java.lang.Object> closure) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType recognizeContentTypeFromHeader(org.springframework.cloud.contract.spec.internal.Headers headers) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType recognizeContentTypeFromTestHeader(org.springframework.cloud.contract.spec.internal.Headers headers) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  org.springframework.cloud.contract.spec.internal.MatchingStrategy.Type getEqualsTypeFromContentType(org.springframework.cloud.contract.verifier.util.ContentType contentType) { return (org.springframework.cloud.contract.spec.internal.MatchingStrategy.Type)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType recognizeContentTypeFromContent(groovy.lang.GString gstring) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType recognizeContentTypeFromContent(java.util.Map jsonMap) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType recognizeContentTypeFromContent(byte... bytes) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType recognizeContentTypeFromContent(java.util.List jsonList) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType recognizeContentTypeFromContent(java.lang.String string) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType recognizeContentTypeFromContent(java.lang.Number number) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType recognizeContentTypeFromContent(java.lang.Object object) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  boolean isJsonType(groovy.lang.GString gstring) { return false;}
public static  boolean isXmlType(groovy.lang.GString gString) { return false;}
public static  org.springframework.cloud.contract.verifier.util.ContentType recognizeContentTypeFromMatchingStrategy(org.springframework.cloud.contract.spec.internal.MatchingStrategy.Type type) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  java.lang.String getGroovyMultipartFileParameterContent(java.lang.String propertyName, org.springframework.cloud.contract.spec.internal.NamedProperty propertyValue, groovy.lang.Closure<java.lang.String> bytesFromFile) { return (java.lang.String)null;}
public static  java.lang.String getGroovyMultipartFileParameterContent(java.lang.String propertyName, org.springframework.cloud.contract.spec.internal.NamedProperty propertyValue, java.util.function.Function<org.springframework.cloud.contract.spec.internal.FromFileProperty, java.lang.String> bytesFromFile) { return (java.lang.String)null;}
public static  java.lang.String getJavaMultipartFileParameterContent(java.lang.String propertyName, org.springframework.cloud.contract.spec.internal.NamedProperty propertyValue, java.util.function.Function<org.springframework.cloud.contract.spec.internal.FromFileProperty, java.lang.String> bytesFromFile) { return (java.lang.String)null;}
public static  java.lang.String getJavaMultipartFileParameterContent(java.lang.String propertyName, org.springframework.cloud.contract.spec.internal.NamedProperty propertyValue, groovy.lang.Closure<java.lang.String> bytesFromFile) { return (java.lang.String)null;}
public static  java.lang.String namedPropertyName(org.springframework.cloud.contract.spec.internal.NamedProperty property, java.lang.String quote) { return (java.lang.String)null;}
public static  java.lang.String namedContentTypeNameIfPresent(org.springframework.cloud.contract.spec.internal.NamedProperty property, java.lang.String quote) { return (java.lang.String)null;}
public static  java.lang.String groovyNamedPropertyValue(org.springframework.cloud.contract.spec.internal.NamedProperty property, java.lang.String quote, groovy.lang.Closure<java.lang.String> bytesFromFile) { return (java.lang.String)null;}
public static  java.lang.String javaNamedPropertyValue(org.springframework.cloud.contract.spec.internal.NamedProperty property, java.lang.String quote, groovy.lang.Closure<java.lang.String> bytesFromFile) { return (java.lang.String)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType evaluateClientSideContentType(org.springframework.cloud.contract.spec.internal.Headers contractHeaders, java.lang.Object body) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  org.springframework.cloud.contract.verifier.util.ContentType evaluateServerSideContentType(org.springframework.cloud.contract.spec.internal.Headers contractHeaders, java.lang.Object body) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
public static  groovy.xml.XmlSlurper getXmlSlurperWithDefaultErrorHandler() { return (groovy.xml.XmlSlurper)null;}
public static  java.lang.invoke.MethodHandles.Lookup $getLookup() { return (java.lang.invoke.MethodHandles.Lookup)null;}
}
